@@ -13,15 +13,18 @@
 # For bug reports, support, and new releases: http://launchpad.net/configglue
 #
 ###############################################################################
+from __future__ import unicode_literals
 
 import json
-from ConfigParser import (
+from configparser import (
     NoSectionError,
     NoOptionError,
 )
 from copy import deepcopy
 from inspect import getmembers
 
+from configglue._compat import text_type, string_types
+
 
 __all__ = [
     'BoolOption',
@@ -156,6 +159,9 @@ class Schema(object):
     def __ne__(self, other):
         return not self.__eq__(other)
 
+    def __hash__(self):
+        return id(self)
+
     def is_valid(self):
         """Return whether the schema has a valid structure."""
         explicit_default_section = isinstance(getattr(self, '__main__', None),
@@ -186,7 +192,7 @@ class Schema(object):
         To get options from the default section, specify section='__main__'
 
         """
-        if isinstance(section, basestring):
+        if isinstance(section, string_types):
             section = self.section(section)
         if section is None:
             options = []
@@ -222,6 +228,9 @@ class Section(object):
     def __ne__(self, other):
         return not self.__eq__(other)
 
+    def __hash__(self):
+        return id(self)
+
     def __repr__(self):
         if self.name:
             name = " %s" % self.name
@@ -316,6 +325,9 @@ class Option(object):
     def __ne__(self, other):
         return not self.__eq__(other)
 
+    def __hash__(self):
+        return id(self)
+
     def __repr__(self):
         extra = ' raw' if self.raw else ''
         extra += ' fatal' if self.fatal else ''
@@ -341,7 +353,7 @@ class Option(object):
 
     def to_string(self, value):
         """Return a string representation of the value."""
-        return str(value)
+        return text_type(value)
 
 
 class BoolOption(Option):
@@ -432,6 +444,9 @@ class ListOption(Option):
 
         return equal
 
+    def __hash__(self):
+        return id(self)
+
     def _get_default(self):
         return []
 
@@ -501,6 +516,9 @@ class StringOption(Option):
 
         return equal
 
+    def __hash__(self):
+        return id(self)
+
     def _get_default(self):
         return '' if not self.null else None
 
@@ -514,7 +532,7 @@ class StringOption(Option):
             result = value
         elif self.null:
             result = None if value in (None, 'None') else value
-        elif isinstance(value, basestring):
+        elif isinstance(value, string_types):
             result = value
         else:
             result = repr(value)
@@ -526,7 +544,7 @@ class StringOption(Option):
         return value
 
     def validate(self, value):
-        return (self.null and value is None) or isinstance(value, basestring)
+        return (self.null and value is None) or isinstance(value, string_types)
 
 
 class TupleOption(Option):
@@ -552,6 +570,9 @@ class TupleOption(Option):
 
         return equal
 
+    def __hash__(self):
+        return id(self)
+
     def _get_default(self):
         return ()
 
@@ -620,6 +641,9 @@ class DictOption(Option):
 
         return equal
 
+    def __hash__(self):
+        return id(self)
+
     def _get_default(self):
         default = {}
         for key, value in self.spec.items():
@@ -683,7 +707,7 @@ class DictOption(Option):
                     if not raw:
                         value = option.default
                     else:
-                        value = unicode(option.default)
+                        value = text_type(option.default)
                     result[key] = value
         return result
 
